#!/bin/sh

# if this is part of a distcheck action, then this script
# will be executed in a different directory
# than the one containing it; so capture the path to this script
# as the location of the source directory.
srcdir=`dirname $0`
tmp=`echo ${srcdir}|sed -e 's/^\\\\//g'`
if test "${tmp}" = "${srcdir}" ; then
  srcdir=`pwd`/${srcdir}
  tmp=`echo ${srcdir}|sed -e 's/\\\\$//g'`
  srcdir=${tmp}
fi

# compute the build directory
# Use a trick to get the proper output when using CYGWIN
# to remove e.g. c: in path
cd `pwd`
builddir=`pwd`

# rewrite srcdir for CYGWIN
cd $srcdir
srcdir=`pwd`
cd $builddir

resultsdir="./results"

# Locate some tools
if test -f ./octest.exe ; then
OCTEST=./octest.exe
elif test -f ./octest ; then
OCTEST=./octest
else
echo "octest executable is missing"
exit 1
fi

# Since these tests use a remote server, there is no local
# testdata directory
# Locate the expected directory
expected="${srcdir}/expected"

# Define the octest options (except -m)
OPTIONS="-g -p all"

# Establish a log file

OCLOGFILE=octest.log; export OCLOGFILE

##################################################
# Remote test info
##################################################

REMOTEURL1="http://test.opendap.org:8080/dods/dts"
REMOTETESTS1="\
test.01 test.02 test.03 test.04 test.05 test.06a test.06 test.07a test.07 \
test.21 test.22 test.23 \
test.31 test.32 \
test.50 test.53 test.55 test.56 test.57 \
test.66 test.67 test.68 test.69"

##################################################
# Testing Procedure
##################################################

rm -fr ${resultsdir}
mkdir "${resultsdir}"

rm -f ${OCLOGFILE}

passcount=0
xfailcount=0
failcount=0

echo "*** Testing oc without -m flag and using remote server(s)"

for x in 1 ; do
  case "$x" in
  1) TESTURLPREFIX="$REMOTEURL1"; TESTSET="$REMOTETESTS1";;
  2) TESTURLPREFIX="$REMOTEURL2"; TESTSET="$REMOTETESTS2";;
  esac
  echo "*** Testing remote server: ${TESTURLPREFIX}"
  for x in ${TESTSET} ; do
    url="${TESTURLPREFIX}/$x"
    echo "*** Testing: ${x}"
	# determine if this is an xfailtest
	isxfail=
	for t in ${XFAILTESTS} ; do
	if test "x${t}" = "x${x}" ; then isxfail=1; fi
	done
    ${OCTEST} ${OPTIONS} ${url} > ${resultsdir}/${x}.dmp
    # compare with expected
    if diff -w ${expected}/${x}.dmp ${resultsdir}/${x}.dmp ; then
      echo "*** SUCCEED: ${x}"
      passcount=`expr $passcount + 1`
    elif test "x${isxfail}" = "x1" ; then
      echo "*** XFAIL: ${x}"
      xfailcount=`expr $xfailcount + 1`
    else
      echo "*** FAIL: ${x}"
      failcount=`expr $failcount + 1`
    fi
  done
done

echo "*** Testing oc with -m flag and using remote server(s)"

for x in 1 ; do
  case "$x" in
  1) TESTURLPREFIX="$REMOTEURL1"; TESTSET="$REMOTETESTS1";;
  2) TESTURLPREFIX="$REMOTEURL2"; TESTSET="$REMOTETESTS2";;
  esac
  echo "*** Testing remote server: ${TESTURLPREFIX}"
  for x in ${TESTSET} ; do
    url="${TESTURLPREFIX}/$x"
    echo "*** Testing: ${x}"
	# determine if this is an xfailtest
	isxfail=
	for t in ${XFAILTESTS} ; do
	if test "x${t}" = "x${x}" ; then isxfail=1; fi
	done
    ${OCTEST} -m ${OPTIONS} ${url} > ${resultsdir}/${x}.dmp
    # compare with expected
    if diff -w ${expected}/${x}.dmp ${resultsdir}/${x}.dmp ; then
      echo "*** SUCCEED: ${x}"
      passcount=`expr $passcount + 1`
    elif test "x${isxfail}" = "x1" ; then
      echo "*** XFAIL: ${x}"
      xfailcount=`expr $xfailcount + 1`
    else
      echo "*** FAIL: ${x}"
      failcount=`expr $failcount + 1`
    fi
  done
done

totalcount=`expr $passcount + $failcount + $xfailcount`
okcount=`expr $passcount + $xfailcount`

echo "*** PASSED: ${okcount}/${totalcount} ; ${xfailcount} expected failures ; ${failcount} unexpected failures"

if test "$failcount" -gt 0 ; then
  exit 1
else
  exit 0
fi

