#!/bin/sh

# if this is part of a distcheck action, then this script
# will be executed in a different directory
# than the one containing it; so capture the path to this script
# as the location of the source directory.
srcdir=`dirname $0`
tmp=`echo ${srcdir}|sed -e 's/^\\\\//g'`
if test "${tmp}" = "${srcdir}" ; then
  srcdir=`pwd`/${srcdir}
  tmp=`echo ${srcdir}|sed -e 's/\\\\$//g'`
  srcdir=${tmp}
fi

# compute the build directory
# Use a trick to get the proper output when using CYGWIN
# to remove e.g. c: in path
cd `pwd`
builddir=`pwd`

# rewrite srcdir for CYGWIN
cd $srcdir
srcdir=`pwd`
cd $builddir

resultsdir="./results"

# Locate some tools
if test -f ./octest.exe ; then
OCTEST=./octest.exe
elif test -f ./octest ; then
OCTEST=./octest
elif test -f ./apitest.exe ; then
OCTEST=./apitest.exe
elif test -f ./apitest ; then
OCTEST=./apitest
else
echo "octest executable is missing"
exit 1
fi

# Locate the testdata and expected directory
testdata="${srcdir}/testdata2"
expected="${srcdir}/expected2"

# Define the octest options (except -m)
OPTIONS="-g -p all"

# Establish a log file

OCLOGFILE=octest.log; export OCLOGFILE

##################################################
# Local test info
##################################################

# Define the complete URLS

TESTURLPREFIX="file://${testdata}"

XFAILTESTS=


ACTUALDATA2="bears.nc ber-2002-10-01.nc ceopL2AIRS2-2.nc ceopL2AIRS2.nc \
data.nc fnoc1.nc in1.nc in_2.nc \
in.nc in_no_three_double_dmn.nc in_v.nc saco1.nc \
synth7 synth8 testfile.nc text.nc"

TESTSET="${ACTUALDATA2}"

##################################################
# Testing Procedure
##################################################

rm -r ${resultsdir}
mkdir "${resultsdir}"

rm -f ${OCLOGFILE}

passcount=0
xfailcount=0
failcount=0

echo "*** Testing oc without -m flag."

for x in ${TESTSET} ; do
  url="${TESTURLPREFIX}/$x"
  echo "*** Testing: ${x}"
	# determine if this is an xfailtest
	isxfail=
	for t in ${XFAILTESTS} ; do
	if test "x${t}" = "x${x}" ; then isxfail=1; fi
	done
  ${OCTEST} ${OPTIONS} ${url} > ${resultsdir}/${x}.dmp
  # compare with expected
  if diff -w ${expected}/${x}.dmp ${resultsdir}/${x}.dmp ; then
    echo "*** SUCCEED: ${x}"
    passcount=`expr $passcount + 1`
  elif test "x${isxfail}" = "x1" ; then
    echo "*** XFAIL: ${x}"
    xfailcount=`expr $xfailcount + 1`
  else
    echo "*** FAIL: ${x}"
    failcount=`expr $failcount + 1`
  fi
done

totalcount=`expr $passcount + $failcount + $xfailcount`
okcount=`expr $passcount + $xfailcount`

echo "*** PASSED: ${okcount}/${totalcount} ; ${xfailcount} expected failures ; ${failcount} unexpected failures"

if test "$failcount" -gt 0 ; then
  exit 1
else
  exit 0
fi

